@@ -94,7 +94,8 @@ class Utils:
     @classmethod
     def create_table_statement(cls, table_name: str, fields: OrderedDict, partitions: OrderedDict = None, soft:bool=True ) -> str:
         partition_stmt:str = ''
-        if partitions is not None:
+        pfields = list(partitions.keys())
+        if partitions is not None and len(pfields) > 0:
             partition_sfield = ','.join([f'{field} {dtype}' for field, dtype in zip(partitions.keys(), partitions.values())])
             partition_stmt = f' PARTITIONED BY ({partition_sfield}) '
 
